==> outline_python_api-0.3.0a0.tar.gz: outline_python_api-0.3.0a0/CHANGELOG.md <==
# Changelog

## 0.3.0-alpha (2024-10-14)

Full Changelog: [v0.2.0-alpha...v0.3.0-alpha](https://github.com/yoshino-s/outline-python-api/compare/v0.2.0-alpha...v0.3.0-alpha)

### Features

* **api:** OpenAPI spec update via Stainless API ([#11](https://github.com/yoshino-s/outline-python-api/issues/11)) ([523aaba](https://github.com/yoshino-s/outline-python-api/commit/523aaba5c9c756c185d3ace32bb2126fce142a59))

## 0.2.0-alpha (2024-06-12)

Full Changelog: [v0.1.0-alpha...v0.2.0-alpha](https://github.com/Yoshino-s/outline-python-api/compare/v0.1.0-alpha...v0.2.0-alpha)

### Features

* **api:** OpenAPI spec update via Stainless API ([#8](https://github.com/Yoshino-s/outline-python-api/issues/8)) ([9cb747f](https://github.com/Yoshino-s/outline-python-api/commit/9cb747f33e6fd6e1a0d1e49dd41cc5851213c3df))

## 0.1.0-alpha (2024-06-02)

Full Changelog: [v0.0.1-alpha...v0.1.0-alpha](https://github.com/Yoshino-s/outline-python-api/compare/v0.0.1-alpha...v0.1.0-alpha)

### Features

* **api:** OpenAPI spec update via Stainless API ([#5](https://github.com/Yoshino-s/outline-python-api/issues/5)) ([b2a597f](https://github.com/Yoshino-s/outline-python-api/commit/b2a597fe7f119183cbb7fe09efb0b83e1e8c1077))

## 0.0.1-alpha (2024-05-09)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha](https://github.com/Yoshino-s/outline-python-api/compare/v0.0.1-alpha.0...v0.0.1-alpha)

### Features

* **api:** update via SDK Studio ([039d168](https://github.com/Yoshino-s/outline-python-api/commit/039d168b3dbe47518229ed91c94ee05547321fd1))


### Chores

* go live ([#1](https://github.com/Yoshino-s/outline-python-api/issues/1)) ([9fbea63](https://github.com/Yoshino-s/outline-python-api/commit/9fbea63e5498392678e27d1b96c79e114437ceca))
* update SDK settings ([#3](https://github.com/Yoshino-s/outline-python-api/issues/3)) ([4755701](https://github.com/Yoshino-s/outline-python-api/commit/4755701e5ef210162e5a88abc52fa274a645c55d))

==> outline_python_api-0.4.0a0.tar.gz: outline_python_api-0.4.0a0/CHANGELOG.md <==
# Changelog

## 0.4.0-alpha (2024-10-21)

Full Changelog: [v0.3.0-alpha...v0.4.0-alpha](https://github.com/yoshino-s/outline-python-api/compare/v0.3.0-alpha...v0.4.0-alpha)

### Features

* **api:** api update ([#13](https://github.com/yoshino-s/outline-python-api/issues/13)) ([55bfe60](https://github.com/yoshino-s/outline-python-api/commit/55bfe60eb844c97fc2ac92eaf6e0e2e8e6108f1f))

## 0.3.0-alpha (2024-10-14)

Full Changelog: [v0.2.0-alpha...v0.3.0-alpha](https://github.com/yoshino-s/outline-python-api/compare/v0.2.0-alpha...v0.3.0-alpha)

### Features

* **api:** OpenAPI spec update via Stainless API ([#11](https://github.com/yoshino-s/outline-python-api/issues/11)) ([523aaba](https://github.com/yoshino-s/outline-python-api/commit/523aaba5c9c756c185d3ace32bb2126fce142a59))

## 0.2.0-alpha (2024-06-12)

Full Changelog: [v0.1.0-alpha...v0.2.0-alpha](https://github.com/Yoshino-s/outline-python-api/compare/v0.1.0-alpha...v0.2.0-alpha)

### Features

* **api:** OpenAPI spec update via Stainless API ([#8](https://github.com/Yoshino-s/outline-python-api/issues/8)) ([9cb747f](https://github.com/Yoshino-s/outline-python-api/commit/9cb747f33e6fd6e1a0d1e49dd41cc5851213c3df))

## 0.1.0-alpha (2024-06-02)

Full Changelog: [v0.0.1-alpha...v0.1.0-alpha](https://github.com/Yoshino-s/outline-python-api/compare/v0.0.1-alpha...v0.1.0-alpha)

### Features

* **api:** OpenAPI spec update via Stainless API ([#5](https://github.com/Yoshino-s/outline-python-api/issues/5)) ([b2a597f](https://github.com/Yoshino-s/outline-python-api/commit/b2a597fe7f119183cbb7fe09efb0b83e1e8c1077))

## 0.0.1-alpha (2024-05-09)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha](https://github.com/Yoshino-s/outline-python-api/compare/v0.0.1-alpha.0...v0.0.1-alpha)

### Features

* **api:** update via SDK Studio ([039d168](https://github.com/Yoshino-s/outline-python-api/commit/039d168b3dbe47518229ed91c94ee05547321fd1))


### Chores

* go live ([#1](https://github.com/Yoshino-s/outline-python-api/issues/1)) ([9fbea63](https://github.com/Yoshino-s/outline-python-api/commit/9fbea63e5498392678e27d1b96c79e114437ceca))
* update SDK settings ([#3](https://github.com/Yoshino-s/outline-python-api/issues/3)) ([4755701](https://github.com/Yoshino-s/outline-python-api/commit/4755701e5ef210162e5a88abc52fa274a645c55d))
